import React from 'react';
import styles from '../styles/AlertDialog.module.css';
import {Input} from "@nextui-org/input";
import SignupDialog from "@/components/SignupDialog";
import {preventDefaultEvent} from "@material/list/events";
import Image from "next/image";
import icon_close from "../../public/images/icon-close.svg";
import toast, { Toaster } from 'react-hot-toast';
import {exec} from "child_process";


interface AlertDialogProps {
    onClose: () => void;
    type: string;
    alertTitle: string;
    alertDesc: string;
    onClickYes?: () => void;
    onClickNo?: () => void;
    yesButtonTitle?: string;
    noButtonTitle?: string;
}

const AlertDialog: React.FC<AlertDialogProps> = ({onClose, type, alertTitle, alertDesc, onClickYes, onClickNo, yesButtonTitle, noButtonTitle}) => {
    const [closing, setClosing] = React.useState(false);
    const [showSignupDialog, setShowSignupDialog] = React.useState<boolean>(false);
    const [email, setEmail] = React.useState<string>('');
    const [password, setPassword] = React.useState<string>('');

    React.useEffect(() => {
        const handleKeyDown = (event: KeyboardEvent) => {
            if (event.key === 'Escape') {
                handleClose();
            }
        };

        window.addEventListener('keydown', handleKeyDown);

        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, [onClose]);

    React.useEffect(() => {
    }, []);

    const handleClose = () => {
        setClosing(true);
        setTimeout(() => {
            onClose();
        }, 200); // 애니메이션 시간 (0.3s) 후 onClose 실행
    };

    const runHandleCloseAfterYesFunction = () => {
        if (onClickYes) {
            onClickYes();
        }
        handleClose();
    }

    const runHandleCloseAfterNoFunction = () => {
        if (onClickNo) {
            onClickNo();
        }
        handleClose();
    }

    return (
        <div className={`${styles.overlay} ${closing ? styles.overlayHide : ''}`} style={{zIndex: 100}}
             // onClick={(event) => {
             //     event.preventDefault();
             //     event.stopPropagation();
             //     handleClose();
             // }}
        >

            <div className={`${styles.loginDialogContainer} ${closing ? styles.slideDown : ''}`}>
                <div style={{display: 'flex', alignItems: 'center'}}>
                    <p
                        style={{margin: 0, flex: 1}}
                        className={[styles.largeFont, styles.fontBold].join(" ")}
                    >
                        {alertTitle}
                    </p>
                    {/*<Image src={icon_close} width={20} height={20} alt={'닫기'} onClick={handleClose} />*/}
                </div>

                <div style={{flex: 1, width: '100%', padding: '10px 0px', paddingBottom: '20px'}}>
                    <p
                        style={{margin: 0}}
                        className={[styles.normalFont, styles.grayColor].join(" ")}
                    >
                        {alertDesc}
                    </p>
                </div>


                <div style={{
                    display: 'flex', alignItems: 'center',
                    gap: '10px'
                }}>
                    {
                        type === "choice" ?
                            <>
                                <button
                                    className={styles.noButton}
                                    onClick={runHandleCloseAfterNoFunction}
                                >
                                    {noButtonTitle ? noButtonTitle : "취소"}
                                </button>

                                <button
                                    className={styles.yesButton}
                                    onClick={runHandleCloseAfterYesFunction}
                                >
                                    {yesButtonTitle ? yesButtonTitle : "확인"}
                                </button>
                            </>
                            :
                            <button
                                className={styles.noButton}
                                onClick={handleClose}
                            >
                                {yesButtonTitle ? yesButtonTitle : "확인"}
                            </button>
                    }

                </div>
            </div>


        </div>
    );
};

export default AlertDialog;
