import React from 'react';
import styles from '../styles/Home.module.css';
import Link from "next/link";

interface EventCardProps {
    evtId: string;
    title: string;
    description: string;
    state: string;
    authorNickname: string;
    thumbnail?: any;
}

const EventCard: React.FC<EventCardProps> = ({evtId, title, description, state, authorNickname, thumbnail}) => {
    return (
        <Link href={`/event/${evtId}`} style={{textDecoration: 'none', color: 'inherit'}}>
            <div className={styles.eventCard}>
                <div className={styles.eventImage}>
                    <img
                        src={thumbnail}
                        alt="Event"
                    />
                </div>
                <div className={styles.eventContent}>
                    {
                        state === 'NOT_STARTED' &&
                            <span className={[styles.eventStatus, styles.grayBg].join(" ")}>
                                예정
                            </span>
                    }
                    {
                        state === 'ON_GOING' &&
                            <span className={[styles.eventStatus, styles.primaryBgColor].join(" ")}>
                                진행 중
                            </span>
                    }
                    {
                        state === 'FINISHED' &&
                            <span className={[styles.eventStatus, styles.grayBg].join(" ")}>
                                종료
                            </span>
                    }

                    <p
                        className={[styles.middleFont, styles.fontBold].join(" ")}
                        style={{margin: 0}}
                    >
                        {title}
                    </p>
                    <p
                        className={[styles.smallFont].join(" ")}
                        style={{margin: 0, flex: 1}}
                    >
                        {description}
                    </p>
                    <p
                        className={[styles.extraSmallFont, styles.grayColor].join(" ")}
                        style={{margin: 0, textAlign: "right", width: '100%'}}
                    >
                        {authorNickname}
                    </p>
                </div>
            </div>
        </Link>
    );
};

export default EventCard;
