import React from 'react';
import styles from '../styles/LoginDialog.module.css';
import icon_close from '../../public/images/icon-close.svg';
import {Input} from "@nextui-org/input";
import Image from "next/image";
import toast from "react-hot-toast";


interface LoginDialogProps {
    onClose: () => void;
}

const SignupDialog: React.FC<LoginDialogProps> = ({onClose}) => {
    const [closing, setClosing] = React.useState(false);
    const [email, setEmail] = React.useState<string>('');
    const [password, setPassword] = React.useState<string>('');
    const [passwordConfirm, setPasswordConfirm] = React.useState<string>('');
    const [nickname, setNickname] = React.useState<string>('');

    React.useEffect(() => {
        const handleKeyDown = (event: KeyboardEvent) => {
            if (event.key === 'Escape') {
                handleClose();
            }
        };

        window.addEventListener('keydown', handleKeyDown);

        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, [onClose]);

    const handleClose = () => {
        setClosing(true);
        setTimeout(() => {
            onClose();
        }, 200); // 애니메이션 시간 (0.3s) 후 onClose 실행
    };

    const executeSignup = async () => {
        const res = fetch('https://rd21.cafe24.com:4343/user/register/', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({
                email: email,
                password: password,
                nick_name: nickname
            })
        })
            .then(async (res) => {
                if (res.status === 201) {
                    // 토큰을 로컬 스토리지에 저장
                    handleClose();
                } else if (res.status === 401) {
                    throw new Error("올바르지 않은 요청이에요")
                } else {
                    throw new Error("예기치 못한 오류에요. 나중에 다시 시도하세요")
                }
            });

        toast.promise(res, {
            loading: "가입 요청 중",
            success: '완료! 가입한 내용으로 로그인하세요!',
            error: (err) => err.message
        })

    }



    return (
        <div className={`${styles.overlay} ${closing ? styles.overlayHide : ''}`}
             style={{zIndex: 60}}
        >
            <div className={`${styles.loginDialogContainer} ${closing ? styles.slideDown : ''}`}>
                <div style={{display: 'flex', alignItems: 'center'}}>
                    <p
                        style={{margin: 0, flex: 1}}
                        className={[styles.largeFont, styles.fontBold].join(" ")}
                    >
                        새로 시작해볼까요?
                    </p>
                    <Image src={icon_close} width={20} height={20} alt={'닫기'} onClick={handleClose} />
                </div>


                <div className={styles.inputGroup}>
                    <input type="email" id="email" name="email" value={email} onChange={(evt) => setEmail(evt.target.value)}
                           required placeholder="이메일" style={{marginBottom: '10px'}}
                    />
                    <input type="password" id="password" name="password" value={password} onChange={(evt) => setPassword(evt.target.value)}
                           required placeholder="비밀번호" style={{marginBottom: '10px'}}
                    />
                    <input type="password" id="password_confirm" name="password_confirm" value={passwordConfirm} onChange={(evt) => setPasswordConfirm(evt.target.value)}
                           required placeholder="비밀번호 확인" style={{marginBottom: '10px'}}
                    />
                    <input id="nickname" required value={nickname} onChange={(evt) => setNickname(evt.target.value)}
                           placeholder="닉네임"
                    />
                </div>

                <div style={{
                    display: 'flex', alignItems: 'center',
                    gap: '15px'
                }}>
                    <button className={styles.button} onClick={executeSignup}>
                        가입하기
                    </button>
                </div>


            </div>
        </div>
    );
};

export default SignupDialog;
