import React from 'react';
import styles from '../styles/AlertDialog.module.css';
import {Input} from "@nextui-org/input";
import SignupDialog from "@/components/SignupDialog";
import {preventDefaultEvent} from "@material/list/events";
import Image from "next/image";
import icon_close from "../../public/images/icon-close.svg";
import toast, { Toaster } from 'react-hot-toast';
import {exec} from "child_process";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faCheck, faHourglassHalf, faPhotoFilm, faXmark} from "@fortawesome/free-solid-svg-icons";
import SubmissionEvalViewDialog from "@/components/SubmissionEvalViewDialog";


interface SubmissionEvalDialogProps {
    onClose: () => void;
    eventId: string;
}

const SubmissionEvalDialog: React.FC<SubmissionEvalDialogProps> = ({onClose, eventId}) => {
    const [closing, setClosing] = React.useState(false);
    const [submissions, setSubmissions] = React.useState<any>([]);
    const [showEvalViewDialog, setShowEvalViewDialog] = React.useState<boolean>(false);
    const [selectedViewId, setSelectedViewId] = React.useState<string>('');

    React.useEffect(() => {
        const handleKeyDown = (event: KeyboardEvent) => {
            if (event.key === 'Escape') {
                handleClose();
            }
        };

        window.addEventListener('keydown', handleKeyDown);

        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, [onClose]);

    React.useEffect(() => {
        getSubmissions();
    }, []);

    const handleClose = () => {
        setClosing(true);
        setTimeout(() => {
            onClose();
        }, 200); // 애니메이션 시간 (0.3s) 후 onClose 실행
    };

    const getSubmissions = () => {
        fetch(`https://rd21.cafe24.com:4343/events/submissions/all/${eventId}/`, {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Token ${localStorage.getItem('token')}`
            }
        })
            .then(async (res) => {
                const data: any = await res.json();

                if (res.status === 200) {
                    if (!data.length) {
                        toast.error('제출물이 없어요');
                        handleClose();
                    }
                    setSubmissions(data);
                } else if (res.status === 401) {
                    toast.error('제출물 목록을 가져올 수 없어요. 나중에 다시 시도하세요')
                } else {
                    toast.error("예기치 못한 오류에요. 나중에 다시 시도하세요")
                }
            });

    }

    return (
        <div className={`${styles.overlay} ${closing ? styles.overlayHide : ''}`}
             // onClick={(event) => {
             //     event.preventDefault();
             //     event.stopPropagation();
             //     handleClose();
             // }}
        >
            {
                showEvalViewDialog &&
                    <SubmissionEvalViewDialog
                        onClose={() => {
                            setShowEvalViewDialog(false);
                            getSubmissions();
                        }}
                        eventId={eventId}
                        submissionId={selectedViewId}
                    />
            }

            <div className={`${styles.loginDialogContainer} ${closing ? styles.slideDown : ''}`}>
                <div style={{display: 'flex', alignItems: 'center', marginBottom: '15px'}}>
                    <p
                        style={{margin: 0, flex: 1}}
                        className={[styles.largeFont, styles.fontBold].join(" ")}
                    >
                        {submissions.length}개의 제출물 목록
                    </p>
                    <Image src={icon_close} width={20} height={20} alt={'닫기'} onClick={handleClose} />
                </div>
                {/*<p*/}
                {/*    className={[styles.extraSmallFont, styles.grayColor].join(" ")}*/}
                {/*    style={{margin: '5px 0px', marginBottom: '15px'}}*/}
                {/*>*/}
                {/*    제출됨: {new Date(submission?.created_at).toLocaleString()}*/}
                {/*</p>*/}

                <div style={{
                    width: '100%',
                    flex: 1,
                }}>
                    <div style={{
                        display: 'flex', flexDirection: 'column', gap: '10px'
                    }}>
                        {
                            submissions.map((submit: any, idx: number) => (
                                <div
                                    key={idx}
                                    style={{display: 'flex', gap: '10px'}}
                                    onClick={() => {
                                        setSelectedViewId(submit.id);
                                        setShowEvalViewDialog(true);
                                    }}
                                >
                                    {
                                        submit.eval_state === 'waiting' &&
                                        <FontAwesomeIcon
                                            icon={faHourglassHalf}
                                            style={{color: 'gray'}}
                                        />
                                    }
                                    {
                                        submit.eval_state === 'correct' &&
                                        <FontAwesomeIcon
                                            icon={faCheck}
                                            style={{color: 'gray'}}
                                        />
                                    }
                                    {
                                        submit.eval_state === 'incorrect' &&
                                        <FontAwesomeIcon
                                            icon={faXmark}
                                            style={{color: 'gray'}}
                                        />
                                    }

                                    <p style={{
                                        margin: 0, textDecoration: 'underline',
                                        flex: 1, color: 'gray'
                                    }}>
                                        {submit?.author[0]?.user?.nick_name}님의 제출물
                                    </p>
                                </div>
                            ))
                        }
                    </div>
                </div>

            </div>


        </div>
    );
};

export default SubmissionEvalDialog;
