import React from 'react';
import styles from '../styles/AlertDialog.module.css';
import {Input} from "@nextui-org/input";
import SignupDialog from "@/components/SignupDialog";
import {preventDefaultEvent} from "@material/list/events";
import Image from "next/image";
import icon_close from "../../public/images/icon-close.svg";
import toast, { Toaster } from 'react-hot-toast';
import {exec} from "child_process";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faPhotoFilm} from "@fortawesome/free-solid-svg-icons";


interface SubmissionUploadDialogProps {
    onClose: () => void;
    eventId: string;
}

const SubmissionUploadDialog: React.FC<SubmissionUploadDialogProps> = ({onClose, eventId}) => {
    const [closing, setClosing] = React.useState(false);
    const [uploading, setUploading] = React.useState<boolean>(false);
    const [selectedImage, setSelectedImage] = React.useState<string | ArrayBuffer | null>(null);
    const [selectedFile, setSelectedFile] = React.useState<File | null>(null);

    const handleImageUpload = (event: React.ChangeEvent<HTMLInputElement>) => {
        const file = event.target.files?.[0];
        if (file) {
            setSelectedFile(file);
            const reader = new FileReader();
            reader.onloadend = () => {
                setSelectedImage(reader.result);
            };
            reader.readAsDataURL(file);
        }
    };

    React.useEffect(() => {
        const handleKeyDown = (event: KeyboardEvent) => {
            if (event.key === 'Escape') {
                handleClose();
            }
        };

        window.addEventListener('keydown', handleKeyDown);

        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, [onClose]);

    React.useEffect(() => {
    }, []);

    const handleClose = () => {
        setClosing(true);
        setTimeout(() => {
            onClose();
        }, 200); // 애니메이션 시간 (0.3s) 후 onClose 실행
    };

    const uploadSubmission = () => {
        setUploading(true);
        const formData = new FormData();
        formData.append('image1', selectedFile as File);
        const res = fetch(`https://rd21.cafe24.com:4343/events/submissions/create/${eventId}/`, {
            method: 'POST',
            headers: {
                'Authorization': `Token ${localStorage.getItem('token')}`
            },
            body: formData
        })
            .then(async (res) => {
                setUploading(false);
                if (res.status === 200) {
                    handleClose();
                } else if (res.status === 401) {
                    throw new Error("문제가 발생했어요. 나중에 다시 시도하세요")
                } else {
                    throw new Error("예기치 못한 오류에요. 나중에 다시 시도하세요")
                }
            });

        toast.promise(res, {
            loading: "업로드 중",
            success: '사진을 제출했습니다!',
            error: (err) => err.message
        })

    }

    return (
        <div className={`${styles.overlay} ${closing ? styles.overlayHide : ''}`}
             // onClick={(event) => {
             //     event.preventDefault();
             //     event.stopPropagation();
             //     handleClose();
             // }}
        >
            <div className={`${styles.loginDialogContainer} ${closing ? styles.slideDown : ''}`}>
                <div style={{display: 'flex', alignItems: 'center', marginBottom: '15px'}}>
                    <p
                        style={{margin: 0, flex: 1}}
                        className={[styles.largeFont, styles.fontBold].join(" ")}
                    >
                        답변 제출
                    </p>
                    <Image src={icon_close} width={20} height={20} alt={'닫기'} onClick={handleClose} />
                </div>
                {/*<p*/}
                {/*    className={[styles.extraSmallFont, styles.grayColor].join(" ")}*/}
                {/*    style={{margin: '5px 0px', marginBottom: '15px'}}*/}
                {/*>*/}
                {/*    제출됨: {new Date(submission?.created_at).toLocaleString()}*/}
                {/*</p>*/}

                <div style={{
                    width: '100%',
                    flex: 1,
                }}>
                    <input
                        type="file"
                        id="fileInput"
                        style={{ display: 'none' }}
                        accept="image/*"
                        onChange={handleImageUpload}
                    />
                    {selectedImage ? (
                        <img src={selectedImage as string} alt={'제출물 이미지'} onClick={() => document.getElementById('fileInput')?.click()}
                             style={{width: '100%', height: '200px', objectFit: 'cover', marginBottom: '15px', borderRadius: '15px'}}
                        />
                    ) : (
                        <div style={{
                            width: '100%', height: '200px', borderRadius: '15px', backgroundColor: '#c7c7c7', marginBottom: '15px',
                            display: 'flex', flexDirection: 'column', justifyContent: 'center', alignItems: 'center', gap: '10px'
                        }}
                             onClick={() => document.getElementById('fileInput')?.click()}
                        >
                            <FontAwesomeIcon icon={faPhotoFilm} />
                            <p style={{margin: 0, padding: 0}} className={styles.smallFont}>
                                사진 업로드
                            </p>
                        </div>
                    )}

                    <button
                        className={styles.yesButton}
                        onClick={uploadSubmission}
                        style={{width: '100%'}}
                        disabled={!Boolean(selectedFile) || uploading}
                    >
                        제출하기
                    </button>
                </div>

            </div>


        </div>
    );
};

export default SubmissionUploadDialog;
