import React from 'react';
import styles from '../styles/LoginDialog.module.css';
import {Input} from "@nextui-org/input";
import SignupDialog from "@/components/SignupDialog";
import {preventDefaultEvent} from "@material/list/events";
import Image from "next/image";
import icon_close from "../../public/images/icon-close.svg";
import toast, { Toaster } from 'react-hot-toast';
import {exec} from "child_process";


interface SubmissionDialogProps {
    onClose: () => void;
    submissionId: string;
}

const SubmissionViewDialog: React.FC<SubmissionDialogProps> = ({onClose, submissionId}) => {
    const [closing, setClosing] = React.useState(false);
    const [submission, setSubmission] = React.useState<any>({});

    React.useEffect(() => {
        const handleKeyDown = (event: KeyboardEvent) => {
            if (event.key === 'Escape') {
                handleClose();
            }
        };

        window.addEventListener('keydown', handleKeyDown);

        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, [onClose]);

    React.useEffect(() => {
        getSubmission(submissionId);
    }, []);

    const handleClose = () => {
        setClosing(true);
        setTimeout(() => {
            onClose();
        }, 200); // 애니메이션 시간 (0.3s) 후 onClose 실행
    };

    const getSubmission = (submission_id: string) => {
        const res = fetch(`https://rd21.cafe24.com:4343/events/submissions/get/${submission_id}/`, {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json'
            },
        })
            .then(async (res) => {
                const data: any = await res.json();

                if (res.status === 200) {
                    setSubmission(data);
                } else if (res.status === 401) {
                    toast.error("조회 권한이 없어요")
                } else {
                    toast.error("예기치 못한 오류에요. 나중에 다시 시도하세요")
                }
            });

    }

    return (
        <div className={`${styles.overlay} ${closing ? styles.overlayHide : ''}`}
             // onClick={(event) => {
             //     event.preventDefault();
             //     event.stopPropagation();
             //     handleClose();
             // }}
        >
            <div className={`${styles.loginDialogContainer} ${closing ? styles.slideDown : ''}`}>
                <div style={{display: 'flex', alignItems: 'center'}}>
                    <p
                        style={{margin: 0, flex: 1}}
                        className={[styles.largeFont, styles.fontBold].join(" ")}
                    >
                        제출물
                    </p>
                    <Image src={icon_close} width={20} height={20} alt={'닫기'} onClick={handleClose} />
                </div>
                <p
                    className={[styles.extraSmallFont, styles.grayColor].join(" ")}
                    style={{margin: '5px 0px', marginBottom: 0, padding: 0}}
                >
                    제출됨: {new Date(submission?.created_at).toLocaleString()}
                </p>
                <p
                    className={[styles.extraSmallFont, styles.grayColor].join(" ")}
                    style={{margin: '0px 0px', marginTop: 0, marginBottom: '15px'}}
                >
                    심사 상태: {
                        submission?.eval_state === 'waiting' ? '심사 대기 중'
                        :
                            submission?.eval_state === 'correct' ? '정답' : '오답'
                    }
                </p>

                <div style={{
                    width: '100%',
                    flex: 1,
                }}>
                    <img src={submission?.image1} alt={'제출물 이미지'}
                         style={{width: '100%', height: '300px', objectFit: 'cover', borderRadius: '15px'}}
                    />
                </div>

            </div>


        </div>
    );
};

export default SubmissionViewDialog;
