// components/Toast.tsx
import React, { useState, useEffect } from 'react';
import styles from '../styles/Toast.module.css';

interface ToastProps {
    message: string;
    duration?: number;
    onClose: () => void;
}

const Toast: React.FC<ToastProps> = ({ message, duration = 5000, onClose }) => {
    useEffect(() => {
        const timer = setTimeout(() => {
            onClose();
        }, duration);

        return () => clearTimeout(timer);
    }, [duration, onClose]);

    return (
        <div className={styles.toast} onClick={onClose}>
            {message}
        </div>
    );
};

export default Toast;
