import React from 'react';
import styles from '../styles/LoginDialog.module.css';
import {Input} from "@nextui-org/input";
import SignupDialog from "@/components/SignupDialog";
import {preventDefaultEvent} from "@material/list/events";
import Image from "next/image";
import icon_close from "../../public/images/icon-close.svg";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import { faHandPointUp } from "@fortawesome/free-solid-svg-icons";
import toast, { Toaster } from 'react-hot-toast';
import {exec} from "child_process";


interface SubmissionDialogProps {
    onClose: () => void;
    hintImage1Url: string;
    hintImage2Url?: string;
    hintImage3Url?: string;
}

const ViewHintDialog: React.FC<SubmissionDialogProps> = ({onClose, hintImage1Url, hintImage2Url, hintImage3Url}) => {
    const [closing, setClosing] = React.useState(false);
    const [hint1Clicked, setHint1Clicked] = React.useState<boolean>(false);
    const [hint2Clicked, setHint2Clicked] = React.useState<boolean>(false);
    const [hint3Clicked, setHint3Clicked] = React.useState<boolean>(false);

    React.useEffect(() => {
        const handleKeyDown = (event: KeyboardEvent) => {
            if (event.key === 'Escape') {
                handleClose();
            }
        };

        window.addEventListener('keydown', handleKeyDown);

        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, [onClose]);

    React.useEffect(() => {
    }, []);

    const handleClose = () => {
        setClosing(true);
        setTimeout(() => {
            onClose();
        }, 200); // 애니메이션 시간 (0.3s) 후 onClose 실행
    };

    return (
        <div className={`${styles.overlay} ${closing ? styles.overlayHide : ''}`}
             // onClick={(event) => {
             //     event.preventDefault();
             //     event.stopPropagation();
             //     handleClose();
             // }}
        >
            <div className={`${styles.loginDialogContainer} ${closing ? styles.slideDown : ''}`}>
                <div style={{display: 'flex', alignItems: 'center'}}>
                    <p
                        style={{margin: 0, flex: 1}}
                        className={[styles.largeFont, styles.fontBold].join(" ")}
                    >
                        힌트
                    </p>
                    <Image src={icon_close} width={20} height={20} alt={'닫기'} onClick={handleClose} />
                </div>
                <p
                    className={[styles.extraSmallFont, styles.grayColor].join(" ")}
                    style={{margin: '5px 0px', marginBottom: '15px'}}
                >
                    사진을 눌러서 힌트를 확인해보세요.
                </p>

                <div style={{
                    display: 'flex', flexDirection: 'column',
                    gap: '10px'
                }}>
                    <div style={{
                        width: '100%',
                        overflow: 'hidden',
                        height: '200px', borderRadius: '15px'
                    }}>
                        <span style={{
                            width: '100%', height: '100%', display: hint1Clicked ? 'none' : 'flex', flexDirection: 'column',
                            justifyContent: 'center', alignItems: 'center', gap: '5px', backgroundColor: '#c7c7c7'
                        }}
                              onClick={() => setHint1Clicked(true)}
                        >
                            <FontAwesomeIcon icon={faHandPointUp} />
                            <p style={{margin: 0, padding: 0}} className={styles.smallFont}>
                                눌러서 확인하기
                            </p>
                        </span>
                        <img src={hintImage1Url} alt={'첫 번째 힌트 이미지'}
                             style={{width: '100%', height: '100%', objectFit: 'cover', backgroundColor: '#939393'}}
                        />
                    </div>

                    {
                        hintImage2Url &&
                            <div style={{
                                width: '100%',
                                overflow: 'hidden',
                                height: '200px', borderRadius: '15px'
                            }}>
                                <span style={{
                                    width: '100%', height: '100%', display: hint2Clicked ? 'none' : 'flex', flexDirection: 'column',
                                    justifyContent: 'center', alignItems: 'center', gap: '5px', backgroundColor: '#c7c7c7'
                                }}
                                      onClick={() => setHint2Clicked(true)}
                                >
                                    <FontAwesomeIcon icon={faHandPointUp} />
                                    <p style={{margin: 0, padding: 0}} className={styles.smallFont}>
                                        눌러서 확인하기
                                    </p>
                                </span>
                                <img src={hintImage2Url} alt={'두 번째 힌트 이미지'}
                                     style={{width: '100%', height: '100%', objectFit: 'cover'}}
                                />
                            </div>
                    }

                    {
                        hintImage3Url &&
                            <div style={{
                                width: '100%',
                                overflow: 'hidden',
                                height: '200px', borderRadius: '15px'
                            }}>
                                <span style={{
                                    width: '100%', height: '100%', display: hint3Clicked ? 'none' : 'flex', flexDirection: 'column',
                                    justifyContent: 'center', alignItems: 'center', gap: '5px', backgroundColor: '#c7c7c7'
                                }}
                                      onClick={() => setHint3Clicked(true)}
                                >
                                    <FontAwesomeIcon icon={faHandPointUp} />
                                    <p style={{margin: 0, padding: 0}} className={styles.smallFont}>
                                        눌러서 확인하기
                                    </p>
                                </span>
                                <img src={hintImage3Url} alt={'세 번째 힌트 이미지'}
                                     style={{width: '100%', height: '100%', objectFit: 'cover'}}
                                />
                            </div>
                    }
                </div>

            </div>
        </div>
    );
};

export default ViewHintDialog;
