import React from 'react';
import Layout from '../components/Layout';
import styles from '../styles/Home.module.css';
import home_svg from '../../public/images/icon-home.svg';
import search_svg from '../../public/images/icon-search.svg';
import flag_svg from '../../public/images/icon-flag.svg';
import settings_svg from '../../public/images/icon-settings.svg';
import Image from 'next/image'
import EventCard from '../components/EventCard';
import {flag} from "arg";
import LoginDialog from "@/components/LoginDialog";
import Link from "next/link";
import toast, {Toaster} from "react-hot-toast";
import CreateEventDialog from "@/components/CreateEventDialog";
import { faPlus } from "@fortawesome/free-solid-svg-icons";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";

const Home: React.FC = () => {
    const [showLoginDialog, setShowLoginDialog] = React.useState<boolean>(false);
    const [showCreateEventDialog, setShowCreateEventDialog] = React.useState<boolean>(false);
    const [allEvents, setAllEvents] = React.useState<any>([]);
    const [isAuth, setIsAuth] = React.useState(false);

    React.useEffect(() => {
        // 모든 이벤트 불러오기
        fetch(`https://rd21.cafe24.com:4343/events/all/`, {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json',
            }
        })
            .then(async (res) => {
                const data: any = await res.json();

                if (res.status === 200) {
                    setAllEvents(data);
                } else {
                    toast.error("이벤트를 불러올 수 없어요. 나중에 다시 시도해주세요")
                }
            });

        // 인증 정보 저장하기
        if (localStorage.getItem('token')) {
            setIsAuth(!isAuth);
        } else {
            setIsAuth(false);
        }
    }, []);

    const executeLogout = () => {
        const res = fetch('https://rd21.cafe24.com:4343/user/logout/', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Token ${localStorage.getItem('token')}`
            },
            body: JSON.stringify({})
        })
            .then((res) => {
                if (res.status === 200) {
                    // 토큰을 로컬 스토리지에 저장
                    setIsAuth(false);
                    localStorage.removeItem('token');
                    localStorage.removeItem('userinfo');
                } else {
                    setIsAuth(false);
                    localStorage.removeItem('token');
                    localStorage.removeItem('userinfo');
                    throw new Error("예기치 못한 오류에요. 나중에 다시 시도하세요");
                }
            });

        toast.promise(res, {
            loading: "로그아웃 중",
            success: '다음에 다시 만나요!',
            error: (err) => err.message
        })
    }

    return (
        <Layout>
            <Toaster />
            {showLoginDialog &&
                <LoginDialog
                    onClose={() => setShowLoginDialog(false)}
                    authState={isAuth}
                    setAuthState={(state: boolean) => setIsAuth(state)}
                />
            }
            {
                showCreateEventDialog &&
                    <CreateEventDialog
                        onClose={() => setShowCreateEventDialog(false)}
                    />
            }

            <div className={styles.container}>
                <header className={styles.header}>
                    {
                        isAuth ?
                            <div style={{display: 'flex', alignItems: 'center', gap: '10px'}}>
                                <p
                                    style={{margin: 0}}
                                    className={[styles.primaryColor, styles.smallFont, styles.fontBold].join(" ")}
                                    onClick={() => setShowLoginDialog(!showLoginDialog)}
                                >
                                    {JSON.parse(localStorage.getItem('userinfo') as string).user.nick_name}님 반가워요!
                                </p>

                                <p
                                    style={{margin: 0}}
                                    className={[styles.grayColor, styles.smallFont].join(" ")}
                                    onClick={executeLogout}
                                >
                                    로그아웃
                                </p>
                            </div>

                            :
                            <p
                                style={{margin: 0, textDecoration: 'underline'}}
                                className={[styles.primaryColor, styles.smallFont, styles.fontBold].join(" ")}
                                onClick={() => setShowLoginDialog(!showLoginDialog)}
                            >
                                로그인해서 더 많이 확인해보세요!
                            </p>
                    }

                    <h1 style={{margin: 0}}>주목할 만한 곳</h1>
                    {/*<div className={styles.location}>*/}
                    {/*    <span className={styles.smallFont}>*/}
                    {/*        {"📍 부산광역시 남포동 기준"}*/}
                    {/*    </span>*/}
                    {/*    <button>변경하기</button>*/}
                    {/*</div>*/}
                </header>

                {/*<section className={[styles.permission, styles.gradientBg].join(" ")}>*/}
                {/*    <Image*/}
                {/*        src={location_svg} alt={'위치 아이콘'}*/}
                {/*        width={60} height={60}*/}
                {/*    />*/}

                {/*    <div className={styles.permissionContent}>*/}
                {/*        <p style={{color: 'white', fontSize: '1.1rem'}}>*/}
                {/*            위치 권한을 허용해주세요*/}
                {/*        </p>*/}
                {/*        <span style={{color: 'white'}}>가까운 이벤트를 자동으로 확인하려면 위치 권한이 필요합니다.</span>*/}
                {/*    </div>*/}
                {/*</section>*/}

                <section className={styles.events}>
                    <p
                        className={[styles.normalFont, styles.primaryColor, styles.fontBold].join((" "))}>
                        최근 생성된 이벤트
                    </p>
                    {
                        allEvents.map((evt: any, idx: number) => (
                            <EventCard
                                key={idx} evtId={evt.id}
                                title={evt.title} description={evt.subtitle}
                                state={evt.state} authorNickname={evt.author.user.nick_name}
                                thumbnail={evt.thumbnail}
                            />
                        ))
                    }
                </section>
            </div>

            <nav className={styles.navbar}>
                <Link href={'/'} style={{textDecoration: 'none', position: 'relative', top: '-4px'}}>
                    <span className={styles.navButtonNormal}>
                        <Image src={home_svg} alt={'홈'} style={{margin: 'auto'}} />
                        {/*<p>홈</p>*/}
                    </span>
                </Link>

                <Link href={'/search'} style={{textDecoration: 'none', position: 'relative', top: '-4px'}}>
                    <span className={styles.navButtonNormal}>
                        <Image src={search_svg} alt={'탐색'} style={{margin: 'auto'}} />
                        {/*<p>탐색</p>*/}
                    </span>
                </Link>


                <span className={styles.navButtonPlus} onClick={() => {
                    if (isAuth) {
                        setShowCreateEventDialog(true);
                    } else {
                        toast.error('먼저 로그인하세요');
                        setShowLoginDialog(true);
                    }
                }}>
                    <FontAwesomeIcon icon={faPlus} style={{color: 'white', height: '30px', margin: 'auto'}} />
                </span>

                <Link href={'/records'} style={{textDecoration: 'none', position: 'relative', top: '-4px'}}>
                    <span className={styles.navButtonNormal}>
                        <Image src={flag_svg} alt={'기록'} style={{margin: 'auto'}} />
                        {/*<p>기록</p>*/}
                    </span>
                </Link>


                <Link href={'/preferences'} style={{textDecoration: 'none', position: 'relative', top: '-6px'}}>
                    <span className={styles.navButtonNormal}>
                        <Image src={settings_svg} alt={'설정'} style={{margin: 'auto'}} />
                        {/*<p>설정</p>*/}
                    </span>
                </Link>
            </nav>
        </Layout>
    );
};

export default Home;
